@@ -1,6 +1,6 @@
 package Net::DNS;
 #
-# $Id: DNS.pm 393 2005-07-01 19:21:52Z olaf $
+# $Id: DNS.pm 539 2005-12-14 10:16:14Z olaf $
 #
 use strict;
 
@@ -41,7 +41,7 @@ BEGIN {
     @ISA     = qw(Exporter DynaLoader);
 
     
-    $VERSION = '0.52';
+    $VERSION = '0.55';
     $HAVE_XS = eval { 
 	local $SIG{'__DIE__'} = 'DEFAULT';
 	__PACKAGE__->bootstrap(); 1 
@@ -181,10 +181,9 @@ sub typesbyval {
     my $val = shift;
     
     die "Net::DNS::typesbyval() argument ($val) is not numeric" unless 
-        $val =~ m/^\s*\d+\s*$/;  
+	$val =~ m/^\s*0*(\d+)\s*$/;
+    $val = $1;
     
-    $val =~ s/\s*//g; 
-    $val =~ s/^0*([0-9]+)/$1/;    #remove leading zeros 
     
     return $typesbyval{$val} if $typesbyval{$val};
     
@@ -834,17 +833,16 @@ the source distribution.
 =head1 COPYRIGHT
 
 Copyright (c) 1997-2002 Michael Fuhr. 
-
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
-
 Portions Copyright (c) 2005 Olaf Kolkman (RIPE NCC)
+Portions Copyright (c) 2006 Olaf Kolkman (NLnet Labs)
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
 
 =head1 AUTHOR INFORMATION
 
-Net::DNS is currently maintained by:
+Net::DNS is currently maintained at NLnet Labs (www.nlnetlabs.nl) by:
         Olaf Kolkman
 	olaf@net-dns.org
 
