@@ -1,9 +1,13 @@
 package Net::DNS::RR;
 #
-# $Id: RR.pm 319 2005-05-30 17:12:09Z olaf $
+# $Id: RR.pm 517 2005-11-21 08:38:47Z olaf $
 #
 use strict;
-use bytes;
+
+BEGIN { 
+    eval { require bytes; }
+} 
+
 use vars qw($VERSION $AUTOLOAD);
 use Carp;
 use Net::DNS;
@@ -11,7 +15,7 @@ use Net::DNS::RR::Unknown;
 
 
 
-$VERSION = (qw$LastChangedRevision: 319 $)[1];
+$VERSION = (qw$LastChangedRevision: 517 $)[1];
 
 =head1 NAME
 
@@ -182,7 +186,7 @@ sub build_regex {
  $a     = Net::DNS::RR->new("foo.example.com. 86400 A 10.1.2.3");
  $mx    = Net::DNS::RR->new("example.com. 7200 MX 10 mailhost.example.com.");
  $cname = Net::DNS::RR->new("www.example.com 300 IN CNAME www1.example.com");
- $txt   = Net::DNS::RR->new("baz.example.com 3600 HS TXT 'text record'");
+ $txt   = Net::DNS::RR->new('baz.example.com 3600 HS TXT "text record"');
 
 Returns a C<Net::DNS::RR> object of the appropriate type and
 initialized from the string passed by the user.  The format of the
@@ -659,7 +663,7 @@ sub _canonicaldata {
 	    my @dname=Net::DNS::name2labels($name);
 	    for (my $i=0;$i<@dname;$i++){
 		$data .= pack ('C',length $dname[$i] );
-		$data .= $dname[$i] ;
+		$data .= lc($dname[$i] );
 	    }
 	    $data .= pack ('C','0');
 	}
@@ -684,9 +688,11 @@ sub _canonicaldata {
 # have domain names in the RDATA and _name2wire is used to convert a
 # domain name to "wire format"
 
+
 sub _canonicalRdata {
-    my $self = shift;
-    my $rdata = $self->rr_rdata;
+    my $self=shift;
+    my $packet=Net::DNS::Packet->new();
+    my $rdata = $self->rr_rdata($packet,0);
     return $rdata;
 }
 
